summaryrefslogtreecommitdiff
path: root/sw/source/core/inc/sectfrm.hxx
diff options
context:
space:
mode:
authorMathias Bauer <mba@openoffice.org>2011-02-09 09:49:44 +0100
committerMathias Bauer <mba@openoffice.org>2011-02-09 09:49:44 +0100
commit53b8f0865ff2e59cb71eaf4c1bdbc829238fde6f (patch)
tree31528d76013d09428fad98a3dbc6265345dbbeb9 /sw/source/core/inc/sectfrm.hxx
parente22a1e2f5c5ed74c22849c9b5bb59dd8f47bffbc (diff)
parent9730661364792059168a06bfbaacf47fc8daf53c (diff)
CWS swlayoutrefactoring: resync to m100
Diffstat (limited to 'sw/source/core/inc/sectfrm.hxx')
-rw-r--r--sw/source/core/inc/sectfrm.hxx65
1 files changed, 37 insertions, 28 deletions
diff --git a/sw/source/core/inc/sectfrm.hxx b/sw/source/core/inc/sectfrm.hxx
index b4ecb4a9f733..d7c5b7cccb66 100644
--- a/sw/source/core/inc/sectfrm.hxx
+++ b/sw/source/core/inc/sectfrm.hxx
@@ -45,30 +45,39 @@ class SwSectionFrm: public SwLayoutFrm, public SwFlowFrm
{
SwSection* pSection;
+<<<<<<< local
void _UpdateAttr( const SfxPoolItem*, const SfxPoolItem*, BYTE &,
+=======
+ void _UpdateAttr( SfxPoolItem*, SfxPoolItem*, sal_uInt8 &,
+>>>>>>> other
SwAttrSetChg *pa = 0, SwAttrSetChg *pb = 0 );
- void _Cut( BOOL bRemove );
+ void _Cut( sal_Bool bRemove );
// Is there a FtnContainer?
// An empty sectionfrm without FtnCont is superfluous
- BOOL IsSuperfluous() const { return !ContainsAny() && !ContainsFtnCont(); }
+ sal_Bool IsSuperfluous() const { return !ContainsAny() && !ContainsFtnCont(); }
void CalcFtnAtEndFlag();
void CalcEndAtEndFlag();
const SwSectionFmt* _GetEndSectFmt() const;
- BOOL IsEndnoteAtMyEnd() const;
+ sal_Bool IsEndnoteAtMyEnd() const;
protected:
virtual void MakeAll();
- virtual BOOL ShouldBwdMoved( SwLayoutFrm *pNewUpper, BOOL bHead, BOOL &rReformat );
+ virtual sal_Bool ShouldBwdMoved( SwLayoutFrm *pNewUpper, sal_Bool bHead, sal_Bool &rReformat );
virtual void Format( const SwBorderAttrs *pAttrs = 0 );
virtual void Modify( const SfxPoolItem*, const SfxPoolItem* );
virtual void SwClientNotify( const SwModify&, const SfxHint& );
public:
+<<<<<<< local
SwSectionFrm( SwSection &, SwFrm* ); //Inhalt wird nicht erzeugt!
SwSectionFrm( SwSectionFrm &, BOOL bMaster );//_Nur_ zum Erzeugen von Master/Follows
+=======
+ SwSectionFrm( SwSection & ); //Inhalt wird nicht erzeugt!
+ SwSectionFrm( SwSectionFrm &, sal_Bool bMaster );//_Nur_ zum Erzeugen von Master/Follows
+>>>>>>> other
~SwSectionFrm();
void Init();
- virtual void CheckDirection( BOOL bVert );
+ virtual void CheckDirection( sal_Bool bVert );
virtual void Cut();
virtual void Paste( SwFrm* pParent, SwFrm* pSibling = 0 );
@@ -77,53 +86,53 @@ public:
inline SwSectionFrm *GetFollow();
SwSectionFrm* FindMaster() const;
- SwCntntFrm *FindLastCntnt( BYTE nMode = 0 );
- inline const SwCntntFrm *FindLastCntnt( BYTE nMode = 0 ) const;
+ SwCntntFrm *FindLastCntnt( sal_uInt8 nMode = 0 );
+ inline const SwCntntFrm *FindLastCntnt( sal_uInt8 nMode = 0 ) const;
inline SwSection* GetSection() { return pSection; }
inline const SwSection* GetSection() const { return pSection; }
- inline void ColLock() { bColLocked = TRUE; }
- inline void ColUnlock() { bColLocked = FALSE; }
+ inline void ColLock() { bColLocked = sal_True; }
+ inline void ColUnlock() { bColLocked = sal_False; }
void CalcFtnCntnt();
void SimpleFormat();
- BOOL IsDescendantFrom( const SwSectionFmt* pSect ) const;
- BOOL HasToBreak( const SwFrm* pFrm ) const;
+ sal_Bool IsDescendantFrom( const SwSectionFmt* pSect ) const;
+ sal_Bool HasToBreak( const SwFrm* pFrm ) const;
void MergeNext( SwSectionFrm* pNxt );
//Zerlegt den pFrm umgebenden SectionFrm in zwei Teile,
//pFrm an den Anfang des 2. Teils
- BOOL SplitSect( SwFrm* pFrm, BOOL bApres );
- void DelEmpty( BOOL bRemove ); // wie Cut(), Follow-Verkettung wird aber mitgepflegt
- BOOL IsToIgnore() const // Keine Groesse, kein Inhalt, muss ignoriert werden
+ sal_Bool SplitSect( SwFrm* pFrm, sal_Bool bApres );
+ void DelEmpty( sal_Bool bRemove ); // wie Cut(), Follow-Verkettung wird aber mitgepflegt
+ sal_Bool IsToIgnore() const // Keine Groesse, kein Inhalt, muss ignoriert werden
{ return !Frm().Height() && !ContainsCntnt(); }
SwFtnContFrm* ContainsFtnCont( const SwFtnContFrm* pCont = NULL ) const;
- BOOL Growable() const;
- SwTwips _Shrink( SwTwips, BOOL bTst );
- SwTwips _Grow ( SwTwips, BOOL bTst );
+ sal_Bool Growable() const;
+ SwTwips _Shrink( SwTwips, sal_Bool bTst );
+ SwTwips _Grow ( SwTwips, sal_Bool bTst );
// A sectionfrm has to maximize, if he has a follow or a ftncontainer at
// the end of the page. A superfluous follow will be ignored,
// if bCheckFollow is set.
- BOOL ToMaximize( BOOL bCheckFollow ) const;
- inline BOOL _ToMaximize() const
- { if( !pSection ) return FALSE; return ToMaximize( FALSE ); }
- BOOL MoveAllowed( const SwFrm* ) const;
- BOOL CalcMinDiff( SwTwips& rMinDiff ) const;
- // Uebergibt man kein bOverSize bzw. FALSE, so ist der Returnwert
+ sal_Bool ToMaximize( sal_Bool bCheckFollow ) const;
+ inline sal_Bool _ToMaximize() const
+ { if( !pSection ) return sal_False; return ToMaximize( sal_False ); }
+ sal_Bool MoveAllowed( const SwFrm* ) const;
+ sal_Bool CalcMinDiff( SwTwips& rMinDiff ) const;
+ // Uebergibt man kein bOverSize bzw. sal_False, so ist der Returnwert
// >0 fuer Undersized-Frames, ==0 sonst.
// Uebergibt man TRUE, so kann es auch einen negativen Returnwert geben,
// wenn der SectionFrm nicht vollstaendig ausgefuellt ist, was z.B. bei
// SectionFrm mit Follow meist vorkommt. Benoetigt wird dies im
// FormatWidthCols, um "Luft" aus den Spalten zu lassen.
- long Undersize( BOOL bOverSize = FALSE );
+ long Undersize( sal_Bool bOverSize = sal_False );
// Groesse an die Umgebung anpassen
- void _CheckClipping( BOOL bGrow, BOOL bMaximize );
+ void _CheckClipping( sal_Bool bGrow, sal_Bool bMaximize );
void InvalidateFtnPos();
void CollectEndnotes( SwLayouter* pLayouter );
const SwSectionFmt* GetEndSectFmt() const
{ if( IsEndnAtEnd() ) return _GetEndSectFmt(); return NULL; }
- static void MoveCntntAndDelete( SwSectionFrm* pDel, BOOL bSave );
+ static void MoveCntntAndDelete( SwSectionFrm* pDel, sal_Bool bSave );
bool IsBalancedSection() const;
@@ -141,7 +150,7 @@ inline SwSectionFrm *SwSectionFrm::GetFollow()
{
return (SwSectionFrm*)SwFlowFrm::GetFollow();
}
-inline const SwCntntFrm *SwSectionFrm::FindLastCntnt( BYTE nMode ) const
+inline const SwCntntFrm *SwSectionFrm::FindLastCntnt( sal_uInt8 nMode ) const
{
return ((SwSectionFrm*)this)->FindLastCntnt( nMode );
}
@@ -77,53 +86,53 @@ public:
// >0 fuer Undersized-Frames, ==0 sonst.
- // Uebergibt man TRUE, so kann es auch einen negativen Returnwert geben,
+ // Uebergibt man sal_True, so kann es auch einen negativen Returnwert geben,
// wenn der SectionFrm nicht vollstaendig ausgefuellt ist, was z.B. bei
// SectionFrm mit Follow meist vorkommt. Benoetigt wird dies im